@@ -416,8 +416,8 @@ class Node(BaseModel):
         for key, val in obj_d.items():
             if isinstance(val, BaseModel):
                 val = val.json()
-            if type(val) is dict:
-                val = json.dumps(val)
+            if isinstance(val, dict):
+                val = json.dumps(jsonable_encoder(val))
             cleaned_set_d[key] = val
         return cleaned_set_d
 
