@@ -31,7 +31,7 @@ def get_fields_and_nested_fields(cls: T.Type[BaseModelType]) -> T.List[str]:
     return [*field_names, "__typename"]
 
 
-class Resolver(BaseModel):
+class Resolver(BaseModel, T.Generic[NodeType]):
     node: T.ClassVar[T.Type[NodeType]]
 
     query_params: QueryParamsType
